@@ -28,7 +28,7 @@ fdgrid init file
 -----------
 """
 
-__version__ = "0.10.1"
+__version__ = "0.11.0"
 
 __all__ = ['mesh',
            'domains',
@@ -36,4 +36,4 @@ __all__ = ['mesh',
            'graphics']
 
 from .domains import Domain, Subdomain, Obstacle
-from .mesh import Mesh, AdaptativeMesh, CurvilinearMesh
+from .mesh import RegularMesh, AdaptativeMesh, CurvilinearMesh
